==> tiktalik-1.0.tar.gz: tiktalik-1.0/tiktalik/error.py <==
# Copyright (c) 2013 Techstorage sp. z o.o.
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of 
# this software and associated documentation files (the "Software"), to deal in 
# the Software without restriction, including without limitation the rights to 
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
# the Software, and to permit persons to whom the Software is furnished to do so, 
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all 
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS 
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER 
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


class TiktalikAPIError(Exception):
	"""
	Raised when an API call fails, either due to network errors
	or when an error is returned by the server.

	Attributes:
		http_status: int - HTTP status code that triggered this error
		description: string - error description returned by the server (might be None)
	"""

	def __init__(self, http_status, data=None):
		self.http_status = http_status
		self.data = data

		if isinstance(data, dict):
			self.description = data["description"]
		else:
			self.description = None

	def __str__(self):
		return "TiktalikAPIError: %s %s" % (self.http_status, self.description)

==> tiktalik-1.6.3.1.tar.gz: tiktalik-1.6.3.1/tiktalik/error.py <==
"""Module tiktalik.error"""
# Copyright (c) 2013 Techstorage sp. z o.o.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.


class TiktalikAPIError(Exception):
    """
    Raised when an API call fails, either due to network errors
    or when an error is returned by the server.

    Attributes:
        http_status: int - HTTP status code that triggered this error
        description: string - error description returned by the server (might be None)
    """

    def __init__(self, http_status, data=None):
        self.http_status = http_status
        self.data = data

        if isinstance(data, dict):
            self.description = data.get("description", None)
        else:
            self.description = None

    def __str__(self):
        return "TiktalikAPIError: %s %s" % (self.http_status, self.description)
